<?php

require_once(__DIR__.'/../payment/easycredit.php');

class ot_easycredit_interest_rate
{

    public $code = "ot_easycredit_interest_rate";
    public $title, $description, $enabled, $output;

    /**
     * @var EasyCreditApiClient
     */
    protected $ec;

    public function __construct()
    {
        $this->title = MODULE_ORDER_TOTAL_EASYCREDIT_INTEREST_RATE_TITLE;
        $this->description = MODULE_ORDER_TOTAL_EASYCREDIT_INTEREST_RATE_DESCRIPTION;
        $this->enabled = ((MODULE_PAYMENT_EASYCREDIT_STATUS == 'True' && $this->check()) ? true : false);
        $this->sort_order = MODULE_ORDER_TOTAL_EASYCREDIT_INTEREST_RATE_SORT_ORDER;

        $this->ec = new EasyCreditApiClient(MODULE_PAYMENT_EASYCREDIT_SHOP_ID, MODULE_PAYMENT_EASYCREDIT_SHOP_TOKEN);

        $this->output = array();
    }

    public function check()
    {
        $check_query = xtc_db_query("SELECT configuration_value FROM ".TABLE_CONFIGURATION." WHERE configuration_key = 'MODULE_ORDER_TOTAL_EASYCREDIT_INTEREST_RATE_SORT_ORDER'");

        return xtc_db_num_rows($check_query);
    }

    public function process()
    {
        global $xtPrice, $order;
        if ($order->info['payment_method'] != 'easycredit'
            || !isset($_SESSION['easycredit_data']['tb_process_identifier'])
        ) {
            return;
        }

        $currentInstallmentPlan = $this->ec->getFinancingDetails($_SESSION['easycredit_data']['tb_process_identifier']);
        if ($currentInstallmentPlan->getInstallmentPlan()) {
            $accruingInterest = $currentInstallmentPlan->getInstallmentPlan()->getInterestRate()->getAccruingInterest();
            $this->output[] = array(
                'title' => 'Zinsen für Ratenzahlung:',
                'text' => $xtPrice->xtcFormat($accruingInterest, true),
                'value' => $accruingInterest,
            );
            $order->info['total'] = $order->info['total'] + $accruingInterest;
        }
    }

    function keys()
    {
        return array('MODULE_ORDER_TOTAL_EASYCREDIT_INTEREST_RATE_SORT_ORDER');
    }

    public function install()
    {
        xtc_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_id, configuration_key, configuration_value, configuration_group_id, sort_order, date_added) VALUES ('', 'MODULE_ORDER_TOTAL_EASYCREDIT_INTEREST_RATE_SORT_ORDER', '90', '6', '2', now())");

    }

    function remove()
    {
        $keys = '';
        $keys_array = $this->keys();

        for ($i = 0; $i < sizeof($keys_array); $i++) {
            $keys .= "'".$keys_array[$i]."',";
        }

        $keys = substr($keys, 0, -1);

        xtc_db_query("DELETE FROM ".TABLE_CONFIGURATION." WHERE configuration_key IN (".$keys.")");
    }
}
